// ======= App Config =======
var configApp = require('./config/app.js');

// ======= Database Config =======
var configDB = require('./config/database.js');
  
// ======= Express =======
var express = require('express');

// ======= Express App =======
var app = express();
var http = require('http').Server(app);

// ======= Socket.io =======
var io = require('socket.io')(http);


// ======= Templating Engine =======
var handlebars = require('express-handlebars');

app.engine('.hbs', handlebars({defaultLayout: 'default', extname: '.hbs'}));
app.set('view engine', '.hbs');


// ======= Static Directories =======
var path = require('path');
app.use(express.static(path.join(__dirname, 'public')));


// ======= Favicon ======= 
// uncomment after placing your favicon in /public
var favicon = require('serve-favicon');
//app.use(favicon(path.join(__dirname, 'public', 'favicon.ico')));

// ======= Log ======= 
var logger = require('morgan');
app.use(logger('dev'));

// ======= Body Parser ======= 
var bodyParser = require('body-parser');
app.use(bodyParser.json());
app.use(bodyParser.urlencoded({ extended: false }));

// ======= Cookie Parser =======
var cookieParser = require('cookie-parser');
app.use(cookieParser());

// ======= Express Session =======
var session = require('express-session');
app.use(session({
    secret: configApp.secret,
    resave: false,
    saveUninitialized: false,
    cookie: { maxAge: 60000 }
}));

// ======= Flash Messages =======
var flash = require('connect-flash');
app.use(flash());


// ======= Models =======
var Account = require('./models/account')();


// ======= Configure Passport =======
var passport = require('passport');
var LocalStrategy = require('passport-local').Strategy;
app.use(passport.initialize());
app.use(passport.session());

passport.use(new LocalStrategy(Account.authenticate()));
passport.serializeUser(Account.serializeUser());
passport.deserializeUser(Account.deserializeUser());

// ======= Connect To Database =======
var mongoose = require('mongoose');
mongoose.connect(configDB.url);


// ======= Require Global Route Middleware  =======
var globalMiddleWare = require('./routes/global_middleware');

// ======= Load Global Route Middleware  =======
globalMiddleWare(app);


// ======= Require Routes =======
var routes = require('./routes/index');
var userRoutes = require('./routes/users');

// ======= Load Routes  =======
routes(app, io, passport, Account);
userRoutes(app, io, passport, Account);


// ======= Require Error Handlers =======
var errorHandlers = require('./routes/error_handlers');

// ======= Load Error Handlers  =======
errorHandlers(app); 


// ======= Server Listen =======
http.listen(configApp.port, function(){
  console.log('The application is listening on localhost:3000.');
});

  