module.exports = function(app, io, passport, Account) {

/* GET views/index.hbs */
app.get('/', function(req, res, next) {
  io.sockets.emit("log message", "A user just connected to the home page.");
  res.render('index', { 
    title: 'Home | A Mumsy Generated Application'
  });
});

/* GET views/about.hbs */ 
app.get('/about', function(req, res, next) {
  io.sockets.emit("log message", "A user just connected to the about page.");
  res.render('about', { title: 'About | A Mumsy Generated Application' });
});

/* GET views/setup.hbs */
app.get('/setup', function(req, res) {
    res.render('setup', { 
      title: 'Setup | A Mumsy Generated Application'
    });
});

/* POST views/setup.hbs */
app.post('/setup', function(req, res) {
    Account.count({}, function( err, count){
      if(count == 0){
        Account.register(new Account({ 
          username: req.body.username,
          email: "",
          admin: true
         }), req.body.password, function(err, account) {
            if (err) {
              req.flash('error', 'There was an error in creating your new account.');
              res.redirect('/setup'); 
            } else {
              req.flash('success', 'Your new admin account was created successfully.');
              res.redirect('/');            }
        });
      } else {
        req.flash('error', 'The initial setup is complete.');
        res.redirect('/');        
      }
    });  

});

/* GET views/logs.hbs */
app.get('/logs', function(req, res) {
    res.render('logs', { 
      title: 'Logs | A Mumsy Generated Application'
    });
});

/* GET views/register.hbs */
app.get('/register', function(req, res) {
    io.sockets.emit("log message", "A user just connected to the register page.");
    res.render('register', { 
      title: 'Register | A Mumsy Generated Application'
    });
});

/* POST views/register.hbs */
app.post('/register', function(req, res) {
  io.sockets.emit("log message", "A user just attempted registration.");
  Account.register(new Account({ 
    username: req.body.username,
    email: ""
   }), req.body.password, function(err, account) {
      if (err) {
        console.log(err);
        io.sockets.emit("log message", "The attempt to register was unsuccessful.\nError: " + err);
        req.flash('error', 'There was an error in creating your new account.');
        res.redirect('/register'); 
      } else {
        io.sockets.emit("log message", "The attempt to register was successful.\nNew User: " + req.body.username);
        req.flash('success', 'Your new account was created successfully.');
        res.redirect('/');            }
  });
    

});

/* GET views/login.hbs */
app.get('/login', function(req, res) {
    io.sockets.emit("log message", "A user just connected to the login page.");
    res.render('login', { 
      title: 'Login | Mumsy' 
    });
});

/* POST views/login.hbs */
app.post('/login', function(req, res, next) {
  passport.authenticate('local', function(err, user, info) {
    if (err) { 
      io.sockets.emit("log message", "A user just got an authentication error.");
      req.flash('error', err);
      return res.redirect('/login'); 
    }
    if (!user) { 
      io.sockets.emit("log message", "A user just failed authentication.");
      return res.redirect('/login'); 
    }
    req.logIn(user, function(err) {
      if (err) { 
        req.flash('error', err);
        return res.redirect('/login'); 
      }
      io.sockets.emit("log message", user.username + " just logged in.");
      return res.redirect('/users/' + user._id);
    });
  })(req, res, next);
});  


/* logout user route */
app.get('/logout', function(req, res) {
  io.sockets.emit("log message", req.user.username + " just logged out.");
  req.logout();
  res.redirect('/');           
});

// route middleware to make sure a user is an admin
function isAdmin(req, res, next) {

    // if user is authenticated in the session, carry on 
    if (req.isAuthenticated()) {
      if (req.user.admin) {
        return next();
      } else {      
      req.flash('error', 'You need to be logged in and an admin to view this page.');        
        res.redirect('/');  
      }
    } else {
      req.flash('error', 'You need to be logged in and an admin to view this page.');       
      res.redirect('/');          
    }
}

};
